package nl.iobyte.themeparkconnector.api.operator;

import nl.iobyte.themeparkconnector.api.operator.objects.AttractionOperator;
import nl.iobyte.themeparkconnector.api.operator.objects.panel.OperatorPanel;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

public class OperatorService {

    private final Map<String, AttractionOperator> operators = new HashMap<>();
    private final Map<String, OperatorPanel> panels = new HashMap<>();
    private final Map<UUID, String> operating = new HashMap<>();

    public void addOperator(AttractionOperator operator) {
        if(operator == null)
            return;

        operators.put(operator.getAttractionID(), operator);
    }

    public boolean hasOperator(String id) {
        return operators.containsKey(id);
    }

    public AttractionOperator getOperator(String id) {
        return operators.get(id);
    }

    public Map<String, AttractionOperator> getOperators() {
        return operators;
    }

    public void addPanel(OperatorPanel panel) {
        if(panel == null)
            return;

        panels.put(panel.getID(), panel);
    }

    public boolean hasPanel(String id) {
        return panels.containsKey(id);
    }

    public OperatorPanel getPanel(String id) {
        return panels.get(id);
    }

    public Map<String, OperatorPanel> getPanels() {
        return panels;
    }

    public void removePanel(String id) {
        panels.remove(id);
    }

    public void startOperating(UUID uuid, String id) {
        AttractionOperator operator = getOperator(id);
        if(operator == null)
            return;

        if(!operator.isAvailable())
            return;

        operator.setClient(uuid);
        operating.put(uuid, id);
    }

    public boolean isOperating(UUID uuid) {
        return operating.containsKey(uuid);
    }

    public void stopOperating(UUID uuid) {
        String id = operating.remove(uuid);
        if(id == null)
            return;

        AttractionOperator operator = getOperator(id);
        if(operator == null)
            return;

        operator.setClient(null);
    }

    public Map<UUID, String> getOperating() {
        return operating;
    }

}
