package nl.iobyte.themeparkconnector.api.operator.objects.panel;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

public class OperatorPanel {

    private final String id;
    private final Map<String, OperatorItem> items;

    public OperatorPanel(String id) {
        this.id = id;
        this.items = new LinkedHashMap<>();
    }

    public OperatorPanel(String id, Map<String, OperatorItem> items) {
        this.id = id;
        this.items = items;
    }

    public String getID() {
        return id;
    }

    public void addItem(OperatorItem item) {
        if(item == null)
            return;

        if(hasItem(item.getID()))
            return;

        items.put(item.getID(), item);
    }

    public void addItems(List<OperatorItem> items) {
        for(OperatorItem item : items)
            addItem(item);
    }

    public void addItems(Map<String, OperatorItem> items) {
        this.items.putAll(items);
    }

    public boolean hasItem(String id) {
        return items.containsKey(id);
    }

    public OperatorItem getItem(String id) {
        return items.get(id);
    }

    public Map<String, OperatorItem> getItems() {
        return items;
    }

    public OperatorPanel copy(String id, Map<String, Map<String, String>> commandMap) {
        Map<String, OperatorItem> items = new LinkedHashMap<>();
        OperatorItem item;
        for(Map.Entry<String, OperatorItem> entrySet : this.items.entrySet()) {
            item = entrySet.getValue();
            items.put(
                    entrySet.getKey(),
                    item.copy(commandMap.containsKey(entrySet.getKey()) ? commandMap.get(entrySet.getKey()) : new LinkedHashMap<>())
            );
        }

        return new OperatorPanel(id, items);
    }

}
