package nl.iobyte.themeparkconnector.api.show;

import com.google.gson.Gson;
import de.tr7zw.changeme.nbtapi.NBTCompound;
import de.tr7zw.changeme.nbtapi.NBTItem;
import nl.iobyte.menuapi.item.ItemBuilder;
import nl.iobyte.themepark.ThemePark;
import nl.iobyte.themeparkconnector.ThemeParkConnector;
import nl.iobyte.themeparkconnector.api.show.objects.Ticket;
import org.bukkit.Bukkit;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.*;

public class ShowService {

    private final SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm");

    public String redeemTicket(UUID uuid, String voucher) {
        if(ThemeParkConnector.getInstance().getEconomy() == null)
            return "No economy manager found";

        if(uuid == null || voucher == null)
            return "Invalid parameters";

        Player player = Bukkit.getPlayer(uuid);
        if(player == null)
            return "Invalid player";

        try {
            ArrayList<Map<String, Object>> resultSet = ThemePark.getInstance().getAPI().getDatabaseService().executeQuery(
                    "remote",
                    "SELECT `shows`.id, `shows`.title, seats.seat, seats.date, `shows`.vault_price, paid FROM seats INNER JOIN `shows`  ON `shows`.id=seats.show_id WHERE uuid=? AND voucher=? AND loaded=0 LIMIT 1",
                    new HashMap<>(){{
                        put(1, uuid.toString().replace("-", ""));
                        put(2, voucher);
                    }}
            );

            if(resultSet == null)
                return "Database error";

            if(resultSet.isEmpty())
                return "No results";

            String id = "";
            String name = "";
            int seat = 0;
            Date date = new Date();
            Ticket ticket = new Ticket(voucher, id, seat, date, uuid);
            for(Map<String, Object> map : resultSet) {
                id = map.get("id").toString();
                double price = Double.parseDouble((String) map.get("vault_price"));
                if(!((boolean) map.get("paid"))) {
                    if (!ThemeParkConnector.getInstance().getEconomy().withdrawPlayer(Bukkit.getOfflinePlayer(uuid), price).transactionSuccess()) {
                        String finalId = id;
                        ThemePark.getInstance().getAPI().getDatabaseService().execute(
                                "remote",
                                "DELETE FROM seats WHERE uuid=? AND voucher=? AND show_id=?",
                                new HashMap<>(){{
                                    put(1, uuid.toString().replace("-", ""));
                                    put(2, voucher);
                                    put(3, finalId);
                                }}
                        );
                        return "Not enough money";
                    }
                }

                name = (String) map.get("title");
                seat = (int) map.get("seat");
                date = (Timestamp) map.get("date");
                ticket = new Ticket(voucher, id, seat, date, uuid);
                String finalId = id;
                ThemePark.getInstance().getAPI().getDatabaseService().execute(
                        "remote",
                        "UPDATE seats SET paid=1 WHERE uuid=? AND voucher=? AND show_id=?",
                        new HashMap<>(){{
                            put(1, uuid.toString().replace("-", ""));
                            put(2, voucher);
                            put(3, finalId);
                        }}
                );
            }

            ItemBuilder builder = new ItemBuilder(Material.PAPER);
            builder.setName("&f" + name);
            List<String> list = new ArrayList<>();
            list.add("&6Seat: &f" + ticket.getSeat());
            list.add("&6Date: &f" +format.format(ticket.getShowDate()));
            builder.setLore(list);

            Gson g = new Gson();
            NBTItem item = new NBTItem(builder.getItem());
            NBTCompound compound = item.addCompound("data");
            compound.setString("ticket", g.toJson(ticket, Ticket.class));

            player.getInventory().addItem(item.getItem());
            return "true";
        } catch(Exception e) {
            e.printStackTrace();
        }

        return "Something went wrong";
    }

    public boolean setValid(Ticket ticket) {
        if(ticket == null)
            return false;

        try {
            int i = ThemePark.getInstance().getAPI().getDatabaseService().executeUpdate(
                    "remote",
                    "UPDATE seats SET loaded=1 WHERE uuid=? AND voucher=? AND show_id=?",
                    new HashMap<>(){{
                        put(1, ticket.getUUID().toString().replace("-", ""));
                        put(2, ticket.getID());
                        put(3, ticket.getShowID());
                    }}
            );

            if(i > 0)
                return true;
        } catch(Exception e) {
            e.printStackTrace();
        }

        return false;
    }

}
